@@ -31,12 +31,19 @@ from typing import Any, Dict, List, Tuple, Type, Union, Callable
 from .logger import get_logger
 
 name = "simple_http_server"
-version = "0.15.0"
+version = "0.16.2"
 
 DEFAULT_ENCODING: str = "UTF-8"
 
 SESSION_COOKIE_NAME: str = "PY_SIM_HTTP_SER_SESSION_ID"
 
+WEBSOCKET_OPCODE_CONTINUATION: int = 0x0
+WEBSOCKET_OPCODE_TEXT: int = 0x1
+WEBSOCKET_OPCODE_BINARY: int = 0x2
+WEBSOCKET_OPCODE_CLOSE: int = 0x8
+WEBSOCKET_OPCODE_PING: int = 0x9
+WEBSOCKET_OPCODE_PONG: int = 0xA
+
 _logger = get_logger("simple_http_server.__init__")
 
 
@@ -518,36 +525,133 @@ class WebsocketSession:
     def is_closed(self) -> bool:
         return False
 
-    def send(self, message: str):
+    def send(self, message: Union[str, bytes], opcode: int = None, chunk_size: int = 0):
         pass
 
-    def send_pone(self, message: str):
+    def send_text(self, message: str, chunk_size: int = 0):
         pass
 
-    def send_ping(self, message: str):
+    def send_binary(self, binary: bytes, chunk_size: int = 0):
+        pass
+
+    def send_file(self, path: str, chunk_size: int = 0):
+        pass
+
+    def send_pone(self, message: bytes):
+        pass
+
+    def send_ping(self, message: bytes):
         pass
 
     def close(self, reason: str):
         pass
 
 
+class WebsocketCloseReason(str):
+
+    def __init__(self,
+                 message: str = "",
+                 code: int = None,
+                 reason: str = '') -> None:
+        self.__message: str = message
+        self.__code: int = code
+        self.__reason: str = reason
+
+    @property
+    def message(self) -> str:
+        return self.__message
+
+    @property
+    def code(self) -> int:
+        return self.__code
+
+    @property
+    def reason(self) -> str:
+        return self.__reason
+
+    def __new__(cls, message: str = "", code: int = "", reason: str = '', **kwargs):
+        obj = super().__new__(cls, message)
+        return obj
+
+
 class WebsocketHandler:
 
     def on_handshake(self, request: WebsocketRequest = None):
+        """
+        "
+        " You can get path/headers/path_values/cookies/query_string/query_parameters from request.
+        " 
+        " You should return a tuple means (http_status_code, headers)
+        "
+        " If status code in (0, None, 101), the websocket will be connected, or will return the status you return. 
+        "
+        " All headers will be send to client
+        "
+        """
         return None
 
     def on_open(self, session: WebsocketSession = None):
+        """
+        " 
+        " Will be called when the connection opened.
+        "
+        """
         pass
 
-    def on_message(self, session: WebsocketSession = None, message_type: str = "", message: Any = None):
+    def on_close(self, session: WebsocketSession = None, reason: WebsocketCloseReason = None):
+        """
+        "
+        " Will be called when the connection closed.
+        "
+        """
+        pass
+
+    def on_ping_message(self, session: WebsocketSession = None, message: bytes = b''):
+        """
+        "
+        " Will be called when receive a ping message. Will send all the message bytes back to client by default.
+        "
+        """
+        session.send_pone(message)
+
+    def on_pong_message(self, session: WebsocketSession = None, message: bytes = ""):
+        """
+        "
+        " Will be called when receive a pong message.
+        "
+        """
         pass
 
     def on_text_message(self, session: WebsocketSession = None, message: str = ""):
+        """
+        "
+        " Will be called when receive a text message.
+        "
+        """
         pass
 
-    def on_close(self, session: WebsocketSession = None, reason: str = ""):
+    def on_binary_message(self, session: WebsocketSession = None, message: bytes = b''):
+        """
+        "
+        " Will be called when receive a binary message if you have not consumed all the bytes in `on_binary_frame` 
+        " method.
+        "
+        """
         pass
 
+    def on_binary_frame(self, session: WebsocketSession = None, fin: bool = False, frame_payload: bytes = b''):
+        """
+        "
+        " If you are sending a continuation binary message to server, this will be called every time a frame is 
+        " received, you can consumed all the bytes in this method, e.g. save all bytes to a file. By doing so, 
+        " you should not return and value in this method. 
+        "
+        " If you does not implement this method or return a True in this method, all the bytes will be caced in
+        " memory and be sent to your `on_binary_message` method.
+        "
+        """
+        return True
+
 
 def _get_class_of_method(method_defind):
     vals = vars(sys.modules[method_defind.__module__])
@@ -841,5 +945,4 @@ def _get_websocket_handlers() -> Dict[str, Type]:
 
 
 def _get_error_pages() -> Dict[str, Callable]:
-    _logger.debug(f"error pages:: {_error_page}")
     return _error_page
