@@ -59,6 +59,9 @@ class LazyCalledLoggerThread:
 
     def start(self):
         if self.coroutine_thread is not None:
+            while not self.coroutine_loop:
+                # wait for the loop ready
+                time.sleep(0.1)
             return
         self.coroutine_thread = Thread(target=self.coroutine_main, name="logger-thread", daemon=self.daemon_threads)
         self.coroutine_thread.start()
@@ -82,13 +85,12 @@ class LazyCalledLoggerThread:
         asyncio.run_coroutine_threadsafe(self._call(logger, record), self.coroutine_loop)
 
 
-_lazy_called_logger_thread: LazyCalledLoggerThread = LazyCalledLoggerThread()
-
-
 class CachingLogger(LazyCalledLogger):
 
+    logger_thread: LazyCalledLoggerThread = LazyCalledLoggerThread()
+
     def callHandlers(self, record):
-        _lazy_called_logger_thread.call_logger_handler(self, record)
+        CachingLogger.logger_thread.call_logger_handler(self, record)
 
 
 class LoggerFactory:
